==> bootstrap-italia-2.0.6.jar: META-INF/resources/webjars/bootstrap-italia/2.0.6/src/js/icons.js <==
import '../svg/it-arrow-down-circle.svg'
import '../svg/it-arrow-down-triangle.svg'
import '../svg/it-arrow-down.svg'
import '../svg/it-arrow-left-circle.svg'
import '../svg/it-arrow-left-triangle.svg'
import '../svg/it-arrow-left.svg'
import '../svg/it-arrow-right-circle.svg'
import '../svg/it-arrow-right-triangle.svg'
import '../svg/it-arrow-right.svg'
import '../svg/it-arrow-up-circle.svg'
import '../svg/it-arrow-up-triangle.svg'
import '../svg/it-arrow-up.svg'
import '../svg/it-ban.svg'
import '../svg/it-behance.svg'
import '../svg/it-bookmark.svg'
import '../svg/it-box.svg'
import '../svg/it-burger.svg'
import '../svg/it-calendar.svg'
import '../svg/it-camera.svg'
import '../svg/it-card.svg'
import '../svg/it-chart-line.svg'
import '../svg/it-check-circle.svg'
import '../svg/it-check.svg'
import '../svg/it-chevron-left.svg'
import '../svg/it-chevron-right.svg'
import '../svg/it-clip.svg'
import '../svg/it-clock.svg'
import '../svg/it-close-big.svg'
import '../svg/it-close-circle.svg'
import '../svg/it-close.svg'
import '../svg/it-code-circle.svg'
import '../svg/it-collapse.svg'
import '../svg/it-comment.svg'
import '../svg/it-copy.svg'
import '../svg/it-delete.svg'
import '../svg/it-designers-italia.svg'
import '../svg/it-download.svg'
import '../svg/it-error.svg'
import '../svg/it-exchange-circle.svg'
import '../svg/it-expand.svg'
import '../svg/it-external-link.svg'
import '../svg/it-facebook-square.svg'
import '../svg/it-facebook.svg'
import '../svg/it-file.svg'
import '../svg/it-files.svg'
import '../svg/it-flag.svg'
import '../svg/it-flickr-square.svg'
import '../svg/it-flickr.svg'
import '../svg/it-folder.svg'
import '../svg/it-fullscreen.svg'
import '../svg/it-funnel.svg'
import '../svg/it-github.svg'
import '../svg/it-google.svg'
import '../svg/it-hearing.svg'
import '../svg/it-help-circle.svg'
import '../svg/it-help.svg'
import '../svg/it-horn.svg'
import '../svg/it-inbox.svg'
import '../svg/it-info-circle.svg'
import '../svg/it-instagram.svg'
import '../svg/it-key.svg'
import '../svg/it-less-circle.svg'
import '../svg/it-link.svg'
import '../svg/it-linkedin-square.svg'
import '../svg/it-linkedin.svg'
import '../svg/it-list.svg'
import '../svg/it-lock.svg'
import '../svg/it-locked.svg'
import '../svg/it-mail.svg'
import '../svg/it-map-marker-circle.svg'
import '../svg/it-map-marker-minus.svg'
import '../svg/it-map-marker-plus.svg'
import '../svg/it-map-marker.svg'
import '../svg/it-maximize-alt.svg'
import '../svg/it-maximize.svg'
import '../svg/it-medium-square.svg'
import '../svg/it-medium.svg'
import '../svg/it-minimize.svg'
import '../svg/it-minus-circle.svg'
import '../svg/it-minus.svg'
import '../svg/it-more-actions.svg'
import '../svg/it-more-items.svg'
import '../svg/it-note.svg'
import '../svg/it-open-source.svg'
import '../svg/it-pa.svg'
import '../svg/it-password-invisible.svg'
import '../svg/it-password-visible.svg'
import '../svg/it-pencil.svg'
import '../svg/it-piattaforme.svg'
import '../svg/it-pin.svg'
import '../svg/it-plug.svg'
import '../svg/it-plus-circle.svg'
import '../svg/it-plus.svg'
import '../svg/it-presentation.svg'
import '../svg/it-print.svg'
import '../svg/it-refresh.svg'
import '../svg/it-restore.svg'
import '../svg/it-rss-square.svg'
import '../svg/it-rss.svg'
import '../svg/it-search.svg'
import '../svg/it-settings.svg'
import '../svg/it-share.svg'
import '../svg/it-software.svg'
import '../svg/it-star-full.svg'
import '../svg/it-star-outline.svg'
import '../svg/it-team-digitale.svg'
import '../svg/it-telegram.svg'
import '../svg/it-telephone.svg'
import '../svg/it-tool.svg'
import '../svg/it-twitter-square.svg'
import '../svg/it-twitter.svg'
import '../svg/it-unlocked.svg'
import '../svg/it-upload.svg'
import '../svg/it-user.svg'
import '../svg/it-video.svg'
import '../svg/it-warning-circle.svg'
import '../svg/it-warning.svg'
import '../svg/it-whatsapp-square.svg'
import '../svg/it-whatsapp.svg'
import '../svg/it-wifi.svg'
import '../svg/it-youtube.svg'
import '../svg/it-zoom-in.svg'
import '../svg/it-zoom-out.svg'

==> bootstrap-italia-2.4.1.jar: META-INF/resources/webjars/bootstrap-italia/2.4.1/src/js/icons.js <==
import '../svg/it-arrow-down-circle.svg'
import '../svg/it-arrow-down-triangle.svg'
import '../svg/it-arrow-down.svg'
import '../svg/it-arrow-left-circle.svg'
import '../svg/it-arrow-left-triangle.svg'
import '../svg/it-arrow-left.svg'
import '../svg/it-arrow-right-circle.svg'
import '../svg/it-arrow-right-triangle.svg'
import '../svg/it-arrow-right.svg'
import '../svg/it-arrow-up-circle.svg'
import '../svg/it-arrow-up-triangle.svg'
import '../svg/it-arrow-up.svg'
import '../svg/it-ban.svg'
import '../svg/it-behance.svg'
import '../svg/it-bookmark.svg'
import '../svg/it-box.svg'
import '../svg/it-burger.svg'
import '../svg/it-calendar.svg'
import '../svg/it-camera.svg'
import '../svg/it-card.svg'
import '../svg/it-chart-line.svg'
import '../svg/it-check-circle.svg'
import '../svg/it-check.svg'
import '../svg/it-chevron-left.svg'
import '../svg/it-chevron-right.svg'
import '../svg/it-clip.svg'
import '../svg/it-clock.svg'
import '../svg/it-close-big.svg'
import '../svg/it-close-circle.svg'
import '../svg/it-close.svg'
import '../svg/it-code-circle.svg'
import '../svg/it-collapse.svg'
import '../svg/it-comment.svg'
import '../svg/it-copy.svg'
import '../svg/it-delete.svg'
import '../svg/it-designers-italia.svg'
import '../svg/it-download.svg'
import '../svg/it-error.svg'
import '../svg/it-exchange-circle.svg'
import '../svg/it-expand.svg'
import '../svg/it-external-link.svg'
import '../svg/it-facebook-square.svg'
import '../svg/it-facebook.svg'
import '../svg/it-figma.svg'
import '../svg/it-figma-square.svg'
import '../svg/it-file.svg'
import '../svg/it-file-audio.svg'
import '../svg/it-file-compressed.svg'
import '../svg/it-file-csv.svg'
import '../svg/it-file-json.svg'
import '../svg/it-file-odp.svg'
import '../svg/it-file-ods.svg'
import '../svg/it-file-odt.svg'
import '../svg/it-file-pdf.svg'
import '../svg/it-file-pdf-ext.svg'
import '../svg/it-file-sheet.svg'
import '../svg/it-file-slides.svg'
import '../svg/it-file-txt.svg'
import '../svg/it-file-video.svg'
import '../svg/it-file-xml.svg'
import '../svg/it-files.svg'
import '../svg/it-flag.svg'
import '../svg/it-flickr-square.svg'
import '../svg/it-flickr.svg'
import '../svg/it-folder.svg'
import '../svg/it-fullscreen.svg'
import '../svg/it-funnel.svg'
import '../svg/it-github.svg'
import '../svg/it-google.svg'
import '../svg/it-hearing.svg'
import '../svg/it-help-circle.svg'
import '../svg/it-help.svg'
import '../svg/it-horn.svg'
import '../svg/it-inbox.svg'
import '../svg/it-info-circle.svg'
import '../svg/it-instagram.svg'
import '../svg/it-key.svg'
import '../svg/it-less-circle.svg'
import '../svg/it-link.svg'
import '../svg/it-linkedin-square.svg'
import '../svg/it-linkedin.svg'
import '../svg/it-list.svg'
import '../svg/it-lock.svg'
import '../svg/it-locked.svg'
import '../svg/it-logout.svg'
import '../svg/it-mail.svg'
import '../svg/it-mail-open.svg'
import '../svg/it-map-marker-circle.svg'
import '../svg/it-map-marker-minus.svg'
import '../svg/it-map-marker-plus.svg'
import '../svg/it-map-marker.svg'
import '../svg/it-mastodon.svg'
import '../svg/it-mastodon-square.svg'
import '../svg/it-maximize-alt.svg'
import '../svg/it-maximize.svg'
import '../svg/it-medium-square.svg'
import '../svg/it-medium.svg'
import '../svg/it-minimize.svg'
import '../svg/it-minus-circle.svg'
import '../svg/it-minus.svg'
import '../svg/it-more-actions.svg'
import '../svg/it-more-items.svg'
import '../svg/it-note.svg'
import '../svg/it-open-source.svg'
import '../svg/it-pa.svg'
import '../svg/it-password-invisible.svg'
import '../svg/it-password-visible.svg'
import '../svg/it-pencil.svg'
import '../svg/it-piattaforme.svg'
import '../svg/it-pin.svg'
import '../svg/it-plug.svg'
import '../svg/it-plus-circle.svg'
import '../svg/it-plus.svg'
import '../svg/it-presentation.svg'
import '../svg/it-print.svg'
import '../svg/it-refresh.svg'
import '../svg/it-restore.svg'
import '../svg/it-rss-square.svg'
import '../svg/it-rss.svg'
import '../svg/it-search.svg'
import '../svg/it-settings.svg'
import '../svg/it-share.svg'
import '../svg/it-software.svg'
import '../svg/it-star-full.svg'
import '../svg/it-star-outline.svg'
import '../svg/it-team-digitale.svg'
import '../svg/it-telegram.svg'
import '../svg/it-telephone.svg'
import '../svg/it-tool.svg'
import '../svg/it-twitter-square.svg'
import '../svg/it-twitter.svg'
import '../svg/it-unlocked.svg'
import '../svg/it-upload.svg'
import '../svg/it-user.svg'
import '../svg/it-video.svg'
import '../svg/it-warning-circle.svg'
import '../svg/it-warning.svg'
import '../svg/it-whatsapp-square.svg'
import '../svg/it-whatsapp.svg'
import '../svg/it-wifi.svg'
import '../svg/it-youtube.svg'
import '../svg/it-zoom-in.svg'
import '../svg/it-zoom-out.svg'
import '../svg/it-pinterest.svg'
import '../svg/it-pinterest-square.svg'
import '../svg/it-quora.svg'
import '../svg/it-quora-square.svg'
import '../svg/it-reddit.svg'
import '../svg/it-reddit-square.svg'
import '../svg/it-slack.svg'
import '../svg/it-slack-square.svg'
import '../svg/it-snapchat.svg'
import '../svg/it-snapchat-square.svg'
import '../svg/it-stackexchange.svg'
import '../svg/it-stackexchange-square.svg'
import '../svg/it-stackoverflow.svg'
import '../svg/it-stackoverflow-square.svg'
import '../svg/it-tiktok.svg'
import '../svg/it-tiktok-square.svg'
import '../svg/it-vimeo.svg'
import '../svg/it-vimeo-square.svg'
